(* Load HEPMath package *)
Needs["HEPMath`"];

(* Work with anti-commuting gamma_5 *)
SetOptions[CalcDiracTraces, AntiCommutingG5->True];

(* Declare external momenta. *)
Declare4DLorentzVectors[k1,k2,p1,p2];

(* Declare QED coupling and muon mass as real *)
DeclareReal[e, m];

(* Helicity element for e^-(k1, s1) e^+(k2, s2) -> mu^-(p1, l1) mu^+(p2, l2) *)
M = (Bar[VSp[k2][s2]].(-I e Ga[mu]).USp[k1][s1])*
    (Bar[USp[p1][l1]].(-I e Ga[nu]).VSp[p2][l2])*
    (- I Eta[mu,nu]/Sqr[p1 + p2]);

(* Squared matrix element *)
Msq = HEPMultiply[M, CC[M]];

(* Perform sum over fermion polarisations.
   Set electron mass to zero. *)
Msq = FermionPolarizationSums[Msq, {k1->0, k2->0, p1->m, p2->m}];


Msq = Msq // CalcDiracTraces //        (* Compute Dirac traces. *)
             HEPExpand //              (* Expand. *)
             HEPDenominatorExpand //   (* Expand denominators. *)
             LorentzContract;          (* Contract Lorentz indices *)

(* Declare kinematic variables.
   sqrts:  centre of mass energy
   ct, st: cosine and sine of the scattering angle
   p:      magnitude of muon momentum in the CM frame *)
DeclareReal[sqrts, ct, st, p];

(* Write p in terms of sqrts and m *)
p = Sqrt[sqrts^2/4 - m^2];

(* Set components of the four-momenta and compute scalar products *)
momentumcomponents = {
  k1 -> {sqrts/2, 0, 0,  sqrts/2},
  k2 -> {sqrts/2, 0, 0, -sqrts/2},
  p1 -> {sqrts/2,  p st, 0,  p ct},
  p2 -> {sqrts/2, -p st, 0, -p ct}
};
Msq = ToComponents[Msq, momentumcomponents,
  (* Simplifications done on the scalar products after substituting components *)
  PostProcess -> (Simplify[Expand[#] /. st^2 -> 1 - ct^2]&)
];

(* Set space-time dimension to 4 and simplify *)
Msq = Simplify[Msq /. Dim -> 4];

(* compare with Peskin, Eq. 5.11, using E = sqrts/2 *)
If[Simplify[4 e^4 ((1 + 4 m^2/sqrts^2) + (1 - 4 m^2/sqrts^2) ct^2) - Msq] =!= 0,
   Print["Squared matrix element disagrees with Peskin & Schroeder!!"]];

(* Print result *)
WriteString[$Output, "|M(e+ e- -> mu+ mu-)|^2:\n"];
Print[Msq];
